--- channels/chan_sip.c.orig	2007-10-02 16:12:35.000000000 +0200
+++ channels/chan_sip.c	2007-10-09 16:30:49.000000000 +0200
@@ -11834,7 +11834,7 @@
 	/* RFC3261 says we must treat every 1xx response (but not 100)
 	   that we don't recognize as if it was 183.
 	*/
-	if (resp > 100 && resp < 200 && resp!=101 && resp != 180 && resp != 183)
+	if (resp > 100 && resp < 200 && resp!=101 && resp != 180 && resp != 182 && resp != 183)
 		resp = 183;
 
  	/* Any response between 100 and 199 is PROCEEDING */
@@ -11874,6 +11874,26 @@
 		check_pendings(p);
 		break;
 
+	case 182:	/* 182 Queued */
+		if (!ast_test_flag(req, SIP_PKT_IGNORE))
+			sip_cancel_destroy(p);
+		if (!ast_test_flag(req, SIP_PKT_IGNORE) && p->owner) {
+			ast_queue_control(p->owner, AST_CONTROL_RINGING);
+			if (p->owner->_state != AST_STATE_UP) {
+				ast_setstate(p->owner, AST_STATE_RINGING);
+			}
+		}
+		if (find_sdp(req)) {
+			p->invitestate = INV_EARLY_MEDIA;
+			res = process_sdp(p, req);
+			if (!ast_test_flag(req, SIP_PKT_IGNORE) && p->owner) {
+				/* Queue a progress frame only if we have SDP in 182 */
+				ast_queue_control(p->owner, AST_CONTROL_PROGRESS);
+			}
+		}
+		check_pendings(p);
+		break;
+
 	case 183:	/* Session progress */
 		if (!ast_test_flag(req, SIP_PKT_IGNORE))
 			sip_cancel_destroy(p);
@@ -12416,6 +12436,11 @@
 			if (sipmethod == SIP_INVITE) 
 				handle_response_invite(p, resp, rest, req, seqno);
 			break;
+		case 182:	/* 182 Queued */
+			if (sipmethod == SIP_INVITE) 
+			        ast_verbose("    -- %s is Queued\n", p->owner->name);
+				handle_response_invite(p, resp, rest, req, seqno);
+			break;
 		case 200:	/* 200 OK */
 			p->authtries = 0;	/* Reset authentication counter */
 			if (sipmethod == SIP_MESSAGE || sipmethod == SIP_INFO) {
